==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaProfilKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.NumerProfilu;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DpsJednostkaProfilKey extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_PROFIL.NUMER
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private NumerProfilu numer;

    /**
     * DPS_JEDNOSTKA_PROFIL.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpsJednostkaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_PROFIL.NUMER
     * @mbggenerated 2014-03-10 10:45:37
     */
    public NumerProfilu getNumer() {
        return numer;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DPS_JEDNOSTKA_PROFIL.NUMER
     *
     * @param numer
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNumer(NumerProfilu numer) {
        this.numer = numer;
    }

    /**
     * @return DPS_JEDNOSTKA_PROFIL.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

    /**
     * DPS_JEDNOSTKA_PROFIL.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaProfilKey other = (DpsJednostkaProfilKey) that;
        return (this.getNumer() == null ? other.getNumer() == null : this.getNumer().equals(other.getNumer()))
            && (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getNumer() == null) ? 0 : getNumer().hashCode());
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", numer=").append(numer);
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaProfilKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.NumerProfilu;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DpsJednostkaProfilKey extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_PROFIL.NUMER
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private NumerProfilu numer;

    /**
     * DPS_JEDNOSTKA_PROFIL.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpsJednostkaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_PROFIL.NUMER
     * @mbggenerated 2014-03-13 16:02:38
     */
    public NumerProfilu getNumer() {
        return numer;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:45
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DPS_JEDNOSTKA_PROFIL.NUMER
     *
     * @param numer
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNumer(NumerProfilu numer) {
        this.numer = numer;
    }

    /**
     * @return DPS_JEDNOSTKA_PROFIL.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

    /**
     * DPS_JEDNOSTKA_PROFIL.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaProfilKey other = (DpsJednostkaProfilKey) that;
        return (this.getNumer() == null ? other.getNumer() == null : this.getNumer().equals(other.getNumer()))
            && (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getNumer() == null) ? 0 : getNumer().hashCode());
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", numer=").append(numer);
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append("]");
        return sb.toString();
    }
}
